import { Observable } from "rxjs";
/**
 * This operator skips all synchronously emitted values from an observable.
 *
 * @example
 * const source$ = new BehaviorSubject<number>(1);
 * const noSyncSource$ = source$.pipe(skipSync);
 *
 * source$.subscribe(console.log);
 * noSyncSource$.subscribe(console.log)
 * source$.next(2);
 *
 * // source$ observer will log 1 & 2
 * // noSycSource$ will only log 2
 *
 * @param {Observable<T>} source$
 * @return {Observable<T>}
 */
declare const skipSync: <T>(source$: Observable<T>) => Observable<T>;
export default skipSync;
